<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>command not found</source>
        <translation>Commande non trouvée</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>Operation successfully completed.</source>
        <translation>L&apos;opération s&apos;est déroulée avec succès.</translation>
    </message>
    <message>
        <source>An error has occurs during the operation.</source>
        <translation>Une erreur s&apos;est produite pendant l&apos;opération.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_new call.</source>
        <translation>Une erreur s&apos;est produite durant l&apos;appel ped_disk_new.</translation>
    </message>
    <message>
        <source>An error has happened during the ped_disk_get_partition call.</source>
        <translation>Une erreur s&apos;est produite durant l&apos;appel ped_disk_get_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_new call.</source>
        <translation>Une erreur s&apos;est produite durant l&apos;appel ped_partition_new.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_add_partition call.</source>
        <translation>Une erreur s&apos;est produite durant l&apos;appel ped_disk_add_partition.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_system call.</source>
        <translation>Une erreur s&apos;est produite pendant l&apos;appel ped_partition_set_system call.</translation>
    </message>
    <message>
        <source>An error has happened during ped_partition_set_flag call.</source>
        <translation>Une erreur s&apos;est produite pendant l&apos;appel ped_partition_set_flag.</translation>
    </message>
    <message>
        <source>An error has happened during ped_disk_delete_partition call.</source>
        <translation>Une erreur s&apos;est produite pendant l&apos;appel ped_disk_delete_partition.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>A program that create NTFS partitions.</source>
        <translation>Un programme qui crée des partitions NTFS.</translation>
    </message>
    <message>
        <source>A program that resize NTFS partitions.</source>
        <translation>Un programme qui redimensionne des partitions NTFS.</translation>
    </message>
    <message>
        <source>A program that create EXT3 partitions.</source>
        <translation>Un programme qui crée des partitions EXT3.</translation>
    </message>
    <message>
        <source>A program that create JFS partitions.</source>
        <translation>Un programme qui crée des partitions JFS.
</translation>
    </message>
    <message>
        <source>A program that create XFS partitions.</source>
        <translation>Un programme qui crée des partitions XFS.
</translation>
    </message>
    <message>
        <source>Cannot read /proc/partitions, QTParted cannot be used!.
Please use a kernel with /proc/partitions support.</source>
        <translation type="obsolete">Impossible de lire le fichier /proc/partitions. QtParted ne peut pas être utilisé. Ajoutez ce support dans votre noyau.</translation>
    </message>
    <message>
        <source>Cannot get parted version.</source>
        <translation>Impossible de récupérer la version de parted.</translation>
    </message>
    <message>
        <source>Parted is too old:
- installed parted version: %1.%2.%3
- required parted version: %4.%5.%6 (or better)

Parted homepage: http://www.gnu.org/software/parted/</source>
        <translation>Votre version de Parted est trop ancienne :
- version installée : %1.%2.%3
- version nécessaire : %4.%5.%6 (ou plus récent)

Site web officiel : http://www.gnu.org/software/parted/</translation>
    </message>
    <message>
        <source>Cannot umount partition device: %1.Please do it by hand first to commit the changes!</source>
        <translation>Impossible de démonter la partition : %1. Merci de le faire à la main avant d&apos;appliquer les modifications !</translation>
    </message>
    <message>
        <source>Utility for mount a filesystem.</source>
        <translation>Utilitaire pour monter un système de fichiers.</translation>
    </message>
    <message>
        <source>Utility for umount a filesystem.</source>
        <translation>Utilitaire pour démonter un système de fichiers.</translation>
    </message>
    <message>
        <source>Utility for grow a xfs filesystem.</source>
        <translation>Utilitaire pour accroître un système de fichiers xfs.</translation>
    </message>
</context>
<context>
    <name>QP_ActionList</name>
    <message>
        <source>Getting info about partition %1.</source>
        <translation>Récupérer les informations de la partition %1.</translation>
    </message>
    <message>
        <source>Creating partition.</source>
        <translation>Création de la partition.</translation>
    </message>
    <message>
        <source>Preparation for removing a partition.</source>
        <translation>Préparation à la suppression de la partition.</translation>
    </message>
    <message>
        <source>Removing a partition.</source>
        <translation>Supression d&apos;une partition en cours.</translation>
    </message>
    <message>
        <source>Preparation for resizing a partition.</source>
        <translation>Préparation au redimensionnement d&apos;une partition.</translation>
    </message>
    <message>
        <source>Resizing a partition.</source>
        <translation>Redimensionnement d&apos;une partition en cours.</translation>
    </message>
    <message>
        <source>Preparation for activating a partition.</source>
        <translation>Préparation de l&apos;activation d&apos;une partition.</translation>
    </message>
    <message>
        <source>Activating a partition.</source>
        <translation>Activation de la partition en cours.</translation>
    </message>
    <message>
        <source>Preparation for formatting a partition.</source>
        <translation>Préparation au formatage de la partition.</translation>
    </message>
    <message>
        <source>Formatting a partition.</source>
        <translation>Formatage d&apos;une partition en cours.</translation>
    </message>
    <message>
        <source>Rescan of the disk.</source>
        <translation>Rafraichissement du disque.</translation>
    </message>
    <message>
        <source>Preparation for moving a partition.</source>
        <translation>Préparation au déplacement d&apos;une partition.</translation>
    </message>
    <message>
        <source>Moving a partition.</source>
        <translation>Déplacement d&apos;une partition en cours.</translation>
    </message>
    <message>
        <source>All operations completed.</source>
        <translation>Toutes les opérations ont été effectuées.</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_new!</source>
        <translation>Erreur critique durant l&apos;appel ped_disk_new !</translation>
    </message>
    <message>
        <source>Critical error during ped_disk_duplicate!</source>
        <translation>Erreur critique durant l&apos;appel ped_disk_duplicate !</translation>
    </message>
    <message>
        <source>Preparation for hiding a partition.</source>
        <translation>Préparation du masquage d&apos;une partition.</translation>
    </message>
    <message>
        <source>Hiding a partition.</source>
        <translation>Masquage d&apos;une partition.</translation>
    </message>
</context>
<context>
    <name>QP_DriveList</name>
    <message>
        <source>No device found. Maybe you&apos;re not using root user?</source>
        <translation>Aucun périphérique trouvé. Peut-être n&apos;êtes-vous pas l&apos;utilisateur root ?</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disques</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Périphérique</translation>
    </message>
</context>
<context>
    <name>QP_FSExt3</name>
    <message>
        <source>Writing superblocks and filesystem.</source>
        <translation>Écriture des superblocks et du système de fichiers.</translation>
    </message>
    <message>
        <source>Writing inode tables.</source>
        <translation>Écriture de la table d&apos;inodes.</translation>
    </message>
    <message>
        <source>There was a problem with mkfs.ext3.</source>
        <translation>Il y a eu un problème avec mkfs.ext3.</translation>
    </message>
</context>
<context>
    <name>QP_FSJfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>Impossible d&apos;agrandir une partition si le disque est occupé</translation>
    </message>
</context>
<context>
    <name>QP_FSNtfs</name>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>Impossible d&apos;agrandir une partition si le disque est occupé</translation>
    </message>
    <message>
        <source>Resizing in progress.</source>
        <translation>Redimensionnement en cours.</translation>
    </message>
    <message>
        <source>Syncing device.</source>
        <translation>Synchronisation du périphérique.</translation>
    </message>
</context>
<context>
    <name>QP_FSReiserFS</name>
    <message>
        <source>No label</source>
        <translation>Pas d&apos;étiquette</translation>
    </message>
</context>
<context>
    <name>QP_FSXfs</name>
    <message>
        <source>There was a problem with mkfs.xfs.</source>
        <translation>Il y a eu un problème avec mkfs.xfs.</translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation>Impossible d&apos;agrandir une partition si le disque est occupé</translation>
    </message>
    <message>
        <source>Error during xfs_grow.</source>
        <translation>Erreur durant xfs_grow.</translation>
    </message>
</context>
<context>
    <name>QP_LibParted</name>
    <message>
        <source>Can&apos;t move extended partitions.</source>
        <translation>Impossible de déplacer des partitions étendues.</translation>
    </message>
    <message>
        <source>Can&apos;t move a partition onto itself. Try using resize, perhaps?</source>
        <translation>Impossible de déplacer une partition sur elle-même. Pourquoi n&apos;essayez-vous pas un redimensionnement ?</translation>
    </message>
    <message>
        <source>The partition is mounted.</source>
        <translation>La partition est montée.</translation>
    </message>
    <message>
        <source>An error happen during ped_geometry_init call.</source>
        <translation>Une erreur s&apos;est produite durant l&apos;appel ped_geometry_init.</translation>
    </message>
    <message>
        <source>An error happen during ped_disk_set_partition_geom call.</source>
        <translation>Une erreur s&apos;est produite durant l&apos;appel ped_disk_set_partition_geom.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_open call.</source>
        <translation>Une erreur s&apos;est produite durant l&apos;appel ped_file_system_open.</translation>
    </message>
    <message>
        <source>An error happen during ped_file_system_resize call.</source>
        <translation>Une erreur s&apos;est produite durant l&apos;appel ped_file_system_resize.</translation>
    </message>
    <message>
        <source>Scanning all disk partitions.</source>
        <translation>Scannage des partitions du disque.</translation>
    </message>
    <message>
        <source>Partition %s is being used.</source>
        <translation>La partition %s est utilisée.</translation>
    </message>
    <message>
        <source>Cannot change the active status on this partition</source>
        <translation>Impossible de changer l&apos;état « actif » de cette partition</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during set_system, please report it!</source>
        <translation>Un bug a été trouvé dans QtParted pendant l&apos;appel set_system. Merci de le signaler !!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during ped_file_system_type_get, please report it!</source>
        <translation>Un bug a été trouvé dans QtParted pendant l&apos;appel ped_file_system_type_get. Merci de le signaler !!</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>C&apos;est une partition virtuelle. Vous ne pouvez pas agir dessus. Utilisez l&apos;annulation.</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;resize&quot; scan, please report it!</source>
        <translation>Un bug a été trouvé dans QtParted pendant le rafraichissement du redimensionnement. Merci de le signaler !!</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;mkfs&quot; scan, please report it!</source>
        <translation>Un bug a été trouvé dans QtParted pendant le rafraichissement  de « mkfs ». Merci de le signaler !!</translation>
    </message>
    <message>
        <source>Error committing device.
This can happen when a device is mounted in the disk.
Try to unmount all partitions on this disk.
Please read the FAQ for this kind of error!</source>
        <translation>Erreur pendant la mise à jour du périphérique.
Ceci peut se produire lorsqu&apos;une partition du disque au moins est montée.
Essayez de démonter toutes les partitions de ce disque.
Merci de lire la FAQ pour ce type d&apos;erreur !</translation>
    </message>
    <message>
        <source>A bug was found in QTParted during &quot;move&quot; scan, please report it!</source>
        <translation>Un bug a été trouvé dans QtParted pendant le rafraichissement du déplacement. Merci de signaler ce bug !</translation>
    </message>
    <message>
        <source>Cannot change the hidden status on this partition</source>
        <translation>Impossible de changer l&apos;état « masqué » de cette partition</translation>
    </message>
</context>
<context>
    <name>QP_MainWindow</name>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Quit from the application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <source>&amp;Property</source>
        <translation>&amp;Propriété</translation>
    </message>
    <message>
        <source>Property</source>
        <translation>Propriété</translation>
    </message>
    <message>
        <source>Property of the selected partition</source>
        <translation>Propriété de la partition sélectionnée</translation>
    </message>
    <message>
        <source>&amp;Create</source>
        <translation>&amp;Créer</translation>
    </message>
    <message>
        <source>Create a new partition</source>
        <translation>Créer une nouvelle partition</translation>
    </message>
    <message>
        <source>&amp;Resize</source>
        <translation>&amp;Redimensionner</translation>
    </message>
    <message>
        <source>Resize</source>
        <translation>Redimensionner</translation>
    </message>
    <message>
        <source>Resize a partition</source>
        <translation>Redimensionner une partition</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Déplacer</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Déplacer</translation>
    </message>
    <message>
        <source>Move a partition</source>
        <translation>Déplacer une partition</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Effacer</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Delete a new partition</source>
        <translation>Effacer une partition</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Operations</source>
        <translation>&amp;Opérations</translation>
    </message>
    <message>
        <source>this is a %1 partition
it start at: %2 and end at: %3
it can grow left: %4 and right: %5
the filesystem is: %6</source>
        <translation>Cette partition est une partition %1
Elle débute à : %2 et finit à : %3
Elle peut être aggrandie sur la gauche à %4 et sur la droite à %5
Son système de fichier est : %6</translation>
    </message>
    <message>
        <source>Enter &lt;b&gt;What&apos;s This&lt;/b&gt; modeIt enables the user to ask for help about widgets on the screen.</source>
        <translation>Entrez &lt;b&gt;Qu&apos;est-ce que c&apos;est&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Créer</translation>
    </message>
    <message>
        <source>What&apos;s &amp;This</source>
        <translation>Qu&apos;est-ce que &amp;c&apos;est</translation>
    </message>
    <message>
        <source>What&apos;s This</source>
        <translation>Qu&apos;est-ce que c&apos;est</translation>
    </message>
    <message>
        <source>About QT</source>
        <translation>À propos de QT</translation>
    </message>
    <message>
        <source>Information about QT</source>
        <translation>Informations sur QT</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>About &amp;QTParted</source>
        <translation>À propos de QT&amp;Parted</translation>
    </message>
    <message>
        <source>About QTParted</source>
        <translation>À propos de QTParted</translation>
    </message>
    <message>
        <source>Information about QTParted</source>
        <translation>Informations sur QTParted</translation>
    </message>
    <message>
        <source>About Q&amp;T</source>
        <translation>À propos de &amp;QT</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos de</translation>
    </message>
    <message>
        <source>An internal error happened during partition scan.
This means that you cannot resize or move this partition.</source>
        <translation>Une erreur interne est survenue pendant le scannage de la partition.
Il n&apos;est pas possible de redimensionner ou de déplacer cette partition.</translation>
    </message>
    <message>
        <source>&amp;Configuration...</source>
        <translation>&amp;Configuration...</translation>
    </message>
    <message>
        <source>Configuration of QTParted</source>
        <translation>Configuration de QTParted</translation>
    </message>
    <message>
        <source>Open the configuration dialog</source>
        <translation>Ouvrir la fenêtre de configuration</translation>
    </message>
    <message>
        <source>&amp;Disks</source>
        <translation>&amp;Disques</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Options</translation>
    </message>
    <message>
        <source>Getting devices</source>
        <translation>Recherche des périphériques</translation>
    </message>
    <message>
        <source>load user settings</source>
        <translation>Chargement des réglages utilisateur</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Prêt</translation>
    </message>
    <message>
        <source>primary</source>
        <translation>primaire</translation>
    </message>
    <message>
        <source>logical</source>
        <translation>logique</translation>
    </message>
    <message>
        <source>extended</source>
        <translation>étendue</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Undo last operation</source>
        <translation>Annuler la dernière opération</translation>
    </message>
    <message>
        <source>&amp;Commit</source>
        <translation>&amp;Effectuer</translation>
    </message>
    <message>
        <source>Commit</source>
        <translation>Effectuer
</translation>
    </message>
    <message>
        <source>Commit all operations</source>
        <translation>Effectue toutes les opérations en attente</translation>
    </message>
    <message>
        <source>Set Active...</source>
        <translation>Activer...</translation>
    </message>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>C&apos;est une partition virtuelle. Il est impossible de la modifier. Merci d&apos;utiliser l&apos;annulation.</translation>
    </message>
    <message>
        <source>(No Active on Drive)</source>
        <translation>(Rien d&apos;actif sur le disque)</translation>
    </message>
    <message>
        <source>Currently active partition: %1
Change active partition to: %2

Are you sure you want to change the active partition?</source>
        <translation>Partition active actuellement : %1
Nouvelle partition active : %2

Êtes-vous sûr de vouloir changer la partition active de cette façon ?</translation>
    </message>
    <message>
        <source>&amp;Format</source>
        <translation>&amp;Formatage</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatage</translation>
    </message>
    <message>
        <source>Format a new partition</source>
        <translation>Formatte une nouvelle partition</translation>
    </message>
    <message>
        <source>&amp;Device property</source>
        <translation>&amp;Propriétés du périphérique</translation>
    </message>
    <message>
        <source>&amp;Make a new Partition Table</source>
        <translation>&amp;Créer une nouvelle table des partitions</translation>
    </message>
    <message>
        <source>This will make the partition table</source>
        <translation>Ceci va créer une nouvelle table des partitions</translation>
    </message>
    <message>
        <source>You&apos;re going to loose all partition data! Are you sure? :)</source>
        <translation>Vous allez perdre toutes les données actuellement contenues dans cette partition. Êtes-vous sûr de vouloir continuer ? :)</translation>
    </message>
    <message>
        <source>detected</source>
        <translation>détecté</translation>
    </message>
    <message>
        <source>none</source>
        <translation>aucun</translation>
    </message>
    <message>
        <source>You&apos;re going to make a new partition table. Are you sure?
All data will be lost!</source>
        <translation>Vous êtes en train de créer une nouvelle table des partitions. Êtes-vous sûr de vouloir continuer ?
Toutes les données présentes seront perdues !</translation>
    </message>
    <message>
        <source>It was not possible to make a new partition table.</source>
        <translation>Impossible de créer une nouvelle table des partitions.</translation>
    </message>
    <message>
        <source>Device status: readonly.</source>
        <translation>État du périphérique : lecture seule.</translation>
    </message>
    <message>
        <source>Device status: busy.</source>
        <translation>État du périphérique : occupé.</translation>
    </message>
    <message>
        <source>Device status: available.</source>
        <translation>État du périphérique : disponible.</translation>
    </message>
    <message>
        <source>You&apos;re commiting all changes. Warning, you can lost data!
Make sure also that you&apos;re not commiting a busy device...
In other word PLEASE UMOUNT ALL PARTITIONS before commiting changes!</source>
        <translation>Vous allez effectuer tous les changements. Attention, cela peut entrainer la perte de données !
Assurez-vous que le périphérique ne soit pas occupé...
En d&apos;autres termes, MERCI DE DEMONTER TOUTES LES PARTITIONS avant d&apos;effectuer les changements !</translation>
    </message>
    <message>
        <source>&amp;Device</source>
        <translation>&amp;Périphérique</translation>
    </message>
    <message>
        <source>See the property of this disk device</source>
        <translation>Voir les propriétés de ce disque dur</translation>
    </message>
    <message>
        <source>Some information about the disk device</source>
        <translation>Affiche des informations à propos du disque dur</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Masquer</translation>
    </message>
</context>
<context>
    <name>QP_NavView</name>
    <message>
        <source>The following drives have been detected:</source>
        <translation>Les disques suivants ont été détectés :</translation>
    </message>
    <message>
        <source>Drive Info</source>
        <translation>Informations du disque</translation>
    </message>
    <message>
        <source>Device:</source>
        <translation>Périphérique :</translation>
    </message>
    <message>
        <source>Model:</source>
        <translation>Modèle :</translation>
    </message>
    <message>
        <source>Capacity (Mb):</source>
        <translation>Capacité (Mo) :</translation>
    </message>
    <message>
        <source>Length sectors:</source>
        <translation>Taille des secteurs :</translation>
    </message>
    <message>
        <source>No Drive Selected</source>
        <translation>Pas de disque sélectionné</translation>
    </message>
    <message>
        <source>Status: </source>
        <translation>État :</translation>
    </message>
    <message>
        <source>readonly.</source>
        <translation>lecture seule.</translation>
    </message>
    <message>
        <source>busy.</source>
        <translation>occupé.</translation>
    </message>
    <message>
        <source>available.</source>
        <translation>disponible.</translation>
    </message>
</context>
<context>
    <name>QP_PartInfo</name>
    <message>
        <source>This is a virtual partition. You cannot alter it: use undo instead.</source>
        <translation>C&apos;est une partition virtuelle. Il est impossible de la modifier. Merci d&apos;utiliser l&apos;annulation.</translation>
    </message>
    <message>
        <source>Bug during mkfs! Cannot format virtual partitions!</source>
        <translation>Bug dans mkfs ! Impossible de formater des partitions virtuelles !</translation>
    </message>
    <message>
        <source>Cannot enlarge a partition if the disk device is busy</source>
        <translation type="obsolete">Impossible d&apos;agrandir une partition si le disque est occupé</translation>
    </message>
</context>
<context>
    <name>QP_RealListView</name>
    <message>
        <source>Number</source>
        <translation>Numéro</translation>
    </message>
    <message>
        <source>Partition</source>
        <translation>Partition</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Début</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Used space</source>
        <translation>Espace utilisé</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>État</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Vide</translation>
    </message>
    <message>
        <source>Partition table</source>
        <translation>Table des partitions</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Étiquette</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation>Caché</translation>
    </message>
</context>
<context>
    <name>QP_UIConfig</name>
    <message>
        <source>Configuration</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <source>QTParted &amp;layout</source>
        <translation>&amp;Aspect de QTParted</translation>
    </message>
    <message>
        <source>Chart and ListBox</source>
        <translation>Graphique et zone de liste</translation>
    </message>
    <message>
        <source>Only Chart</source>
        <translation>Graphique seul</translation>
    </message>
    <message>
        <source>Only ListBox</source>
        <translation>Zone de liste seule</translation>
    </message>
    <message>
        <source>&amp;External Tools</source>
        <translation>&amp;Programmes externes</translation>
    </message>
    <message>
        <source>&amp;Full executable path</source>
        <translation>&amp;Chemin d&apos;accès complet des exécutables</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>QP_UICreate</name>
    <message>
        <source>Create partition</source>
        <translation>Créer une partition</translation>
    </message>
    <message>
        <source>&amp;Size:</source>
        <translation>&amp;Taille :</translation>
    </message>
    <message>
        <source>Create &amp;as:</source>
        <translation>Créer &amp;comme :</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Étiquette :</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>&amp;Type de partition :</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>&amp;Beginning of unallocated space</source>
        <translation>&amp;Début de l&apos;espace non alloué</translation>
    </message>
    <message>
        <source>&amp;End of unallocated space</source>
        <translation>&amp;Fin de l&apos;espace non alloué</translation>
    </message>
    <message>
        <source>Pe&amp;rcent of unallocated space:</source>
        <translation>&amp;Pourcentage de l&apos;espace non alloué :</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>QP_UIDeviceProperty</name>
    <message>
        <source>Device property</source>
        <translation>Propriétés du périphérique</translation>
    </message>
    <message>
        <source>Device short name</source>
        <translation>Nom court du périphérique</translation>
    </message>
    <message>
        <source>Device long name</source>
        <translation>Nom long du périphérique</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
</context>
<context>
    <name>QP_UIFormat</name>
    <message>
        <source>Format partition</source>
        <translation>Formater la partition</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;Partition Type:</source>
        <translation>&amp;Type de partition :</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Nom de volume :</translation>
    </message>
</context>
<context>
    <name>QP_UIProgress</name>
    <message>
        <source>Progress</source>
        <translation>Avancement</translation>
    </message>
    <message>
        <source>Progress:</source>
        <translation>Avancement :</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Time Left:</source>
        <translation>Temps restant :</translation>
    </message>
    <message>
        <source>Current operation:</source>
        <translation>Opération courante :</translation>
    </message>
</context>
<context>
    <name>QP_UIResize</name>
    <message>
        <source>Resize partition</source>
        <translation>Redimensionner la partition</translation>
    </message>
    <message>
        <source>Minimum Size:</source>
        <translation>Taille minimum :</translation>
    </message>
    <message>
        <source>Free Space &amp;Before:</source>
        <translation>Espace libre a&amp;vant :</translation>
    </message>
    <message>
        <source>New Size:</source>
        <translation>Nouvelle taille :</translation>
    </message>
    <message>
        <source>Free Space &amp;After:</source>
        <translation>Espace libre a&amp;près :</translation>
    </message>
    <message>
        <source>It is recommended to backup your data before do this operation!</source>
        <translation>Il vous est vivement recommandé d&apos;effectuer une sauvegarde de vos données avant de réaliser cette opération !</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>QP_dlgAbout</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>QP_dlgCreate</name>
    <message>
        <source>This filesystem cannot be greater of %1</source>
        <translation>Le système de fichiers ne peut pas être plus grand que %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgDevProperty</name>
    <message>
        <source>Devfs is enabled.</source>
        <translation>Devfs est activé.</translation>
    </message>
    <message>
        <source>Devfs is disabled.</source>
        <translation>Devfs n&apos;est pas actif.</translation>
    </message>
    <message>
        <source>Partition table: %1</source>
        <translation>Table des partitions : %1</translation>
    </message>
</context>
<context>
    <name>QP_dlgProgress</name>
    <message>
        <source>Initializing</source>
        <translation>Initialisation</translation>
    </message>
    <message>
        <source>Time Left: %1</source>
        <translation>Temps restant : %1</translation>
    </message>
    <message>
        <source>Operation: %1 of %2.
Current operation: %3</source>
        <translation>Opération : %1 sur %2.
Opération actuelle : %3</translation>
    </message>
    <message>
        <source>Operations completed sucessfully.</source>
        <translation>Les opérations se sont achevées avec succès.</translation>
    </message>
</context>
<context>
    <name>QP_dlgResize</name>
    <message>
        <source>Minimum Size: %1 MB</source>
        <translation>Taille minimum : %1 Mo</translation>
    </message>
    <message>
        <source>Resize partition</source>
        <translation>Redimensionner la partition</translation>
    </message>
    <message>
        <source>Move partition</source>
        <translation>Déplacer la partition</translation>
    </message>
</context>
</TS>
